source_suffix = {
    '.rst': 'restructuredtext',
    '.txt': 'restructuredtext',
    '.md': 'markdown',
}
master_doc = 'index'
project = 'Manuel'
copyright = 'Benji York'
version = '1'
release = '1'
today_fmt = '%Y-%m-%d'
pygments_style = 'sphinx'

html_last_updated_fmt = '%Y-%m-%d'
html_title = 'Manuel Documentation'

todo_include_todos = False
exclude_dirnames = ['manuel.egg-info']
unused_docs = ['manuel/capture']
extensions = [
    "myst_parser",
    "sphinx_copybutton",
]
